@@ -1,7 +1,7 @@
 /*
   This file is part of KAddressBook Kontact Plugin.
 
-  SPDX-FileCopyrightText: 2009-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,10 +12,10 @@
 
 #include <KontactInterface/Core>
 
-#include <QAction>
-#include <KActionCollection>
 #include "kaddressbookplugin_debug.h"
+#include <KActionCollection>
 #include <KLocalizedString>
+#include <QAction>
 
 #include <QIcon>
 
@@ -30,34 +30,25 @@ KAddressBookPlugin::KAddressBookPlugin(KontactInterface::Core *core, const QVari
 {
     setComponentName(QStringLiteral("kaddressbook"), i18n("KAddressBook"));
 
-    QAction *action
-        = new QAction(QIcon::fromTheme(QStringLiteral("contact-new")),
-                      i18nc("@action:inmenu", "New Contact..."), this);
+    QAction *action = new QAction(QIcon::fromTheme(QStringLiteral("contact-new")), i18nc("@action:inmenu", "New Contact..."), this);
     actionCollection()->addAction(QStringLiteral("new_contact"), action);
     connect(action, &QAction::triggered, this, &KAddressBookPlugin::slotNewContact);
-    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_C));
-    //action->setHelpText(
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_C));
+    // action->setHelpText(
     //  i18nc( "@info:status", "Create a new contact" ) );
-    action->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "You will be presented with a dialog where you can create a new contact."));
+    action->setWhatsThis(i18nc("@info:whatsthis", "You will be presented with a dialog where you can create a new contact."));
     insertNewAction(action);
 
-    action
-        = new QAction(QIcon::fromTheme(QStringLiteral("user-group-new")),
-                      i18nc("@action:inmenu", "New Contact Group..."), this);
+    action = new QAction(QIcon::fromTheme(QStringLiteral("user-group-new")), i18nc("@action:inmenu", "New Contact Group..."), this);
     actionCollection()->addAction(QStringLiteral("new_contactgroup"), action);
     connect(action, &QAction::triggered, this, &KAddressBookPlugin::slotNewContactGroup);
-    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_G));
-    //action->setHelpText(
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_G));
+    // action->setHelpText(
     //  i18nc( "@info:status", "Create a new contact group" ) );
-    action->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "You will be presented with a dialog where you can create a new contact group."));
+    action->setWhatsThis(i18nc("@info:whatsthis", "You will be presented with a dialog where you can create a new contact group."));
     insertNewAction(action);
 
-    mUniqueAppWatcher = new KontactInterface::UniqueAppWatcher(
-        new KontactInterface::UniqueAppHandlerFactory<KAddressBookUniqueAppHandler>(), this);
+    mUniqueAppWatcher = new KontactInterface::UniqueAppWatcher(new KontactInterface::UniqueAppHandlerFactory<KAddressBookUniqueAppHandler>(), this);
 }
 
 KAddressBookPlugin::~KAddressBookPlugin()
@@ -152,7 +143,7 @@ int KAddressBookUniqueAppHandler::activate(const QStringList &arguments, const Q
     (void)plugin()->part();
     org::kde::kaddressbook kaddressbook(QStringLiteral("org.kde.kaddressbook"), QStringLiteral("/KAddressBook"), QDBusConnection::sessionBus());
     QDBusReply<bool> reply = kaddressbook.handleCommandLine(arguments);
-    Q_UNUSED(reply);
+    Q_UNUSED(reply)
 
     return KontactInterface::UniqueAppHandler::activate(arguments, workingDir);
 }
