@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,18 +10,21 @@
 #include <KCModule>
 
 #include <QVariant>
-namespace PimCommon {
+namespace PimCommon
+{
 class ConfigurePluginsWidget;
 }
-namespace KAddressBook {
+namespace KAddressBook
+{
 class KCMKaddressbookPluginsConfig : public KCModule
 {
     Q_OBJECT
 public:
-    KCMKaddressbookPluginsConfig(QWidget *parent, const QVariantList &args);
+    explicit KCMKaddressbookPluginsConfig(QWidget *parent, const QVariantList &args);
     void load() override;
     void save() override;
     void defaults() override;
+
 private:
     void slotConfigChanged();
     PimCommon::ConfigurePluginsWidget *mConfigurePluginWidget = nullptr;
