@@ -2,7 +2,7 @@
   This file is part of KAddressBook.
   SPDX-FileCopyrightText: 1996-2002 Mirko Boehm <mirko@kde.org>
   SPDX-FileCopyrightText: Tobias Koenig <tokoe@kde.org>
-  SPDX-FileCopyrightText: 2009-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
@@ -10,10 +10,11 @@
 #ifndef PRINTINGWIZARD_H
 #define PRINTINGWIZARD_H
 
-#include <KContacts/Addressee>
 #include <KAssistantDialog>
+#include <KContacts/Addressee>
 
-namespace KAddressBookImportExport {
+namespace KAddressBookImportExport
+{
 class ContactSelectionWidget;
 }
 class StylePage;
@@ -21,11 +22,13 @@ class StylePage;
 class QItemSelectionModel;
 class QPrinter;
 
-namespace Akonadi {
+namespace Akonadi
+{
 class Collection;
 }
 
-namespace KABPrinting {
+namespace KABPrinting
+{
 class PrintProgress;
 class PrintStyle;
 class PrintStyleFactory;
