@@ -12,9 +12,9 @@
 #include <Akonadi/Contact/ContactsTreeModel>
 
 #include <QApplication>
+#include <QImage>
 #include <QPainter>
 #include <QPainterPath>
-#include <QImage>
 
 StyleContactListDelegate::StyleContactListDelegate(QObject *parent)
     : QStyledItemDelegate(parent)
@@ -35,8 +35,7 @@ void StyleContactListDelegate::paint(QPainter *painter, const QStyleOptionViewIt
         if (mKImageSize.width() > optionRect.size().width()) {
             const qreal width = option.rect.size().width();
             const qreal height = option.rect.size().height();
-            const QMargins fitMargins(0, (qMax(width, height) - qMin(width, height)) / qreal(2),
-                                      0, (qMax(width, height) - qMin(width, height)) / qreal(2));
+            const QMargins fitMargins(0, (qMax(width, height) - qMin(width, height)) / qreal(2), 0, (qMax(width, height) - qMin(width, height)) / qreal(2));
 
             pictureRect = optionRect.marginsRemoved(fitMargins);
         }
@@ -79,8 +78,7 @@ void StyleContactListDelegate::paint(QPainter *painter, const QStyleOptionViewIt
         QImage image(index.data(ContactInfoProxyModel::Roles::PictureRole).value<QImage>());
         if (image.isNull()) {
             const QString initials = index.data(ContactInfoProxyModel::Roles::InitialsRole).value<QString>();
-            painter->drawText(pictureRect, Qt::AlignCenter, painter->fontMetrics().elidedText(initials,
-                                                                                              Qt::ElideRight, pictureRect.width() - qreal(10)));
+            painter->drawText(pictureRect, Qt::AlignCenter, painter->fontMetrics().elidedText(initials, Qt::ElideRight, pictureRect.width() - qreal(10)));
         } else {
             const qreal dpr = qApp->devicePixelRatio();
             image = image.scaled(mKImageSize * dpr, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
@@ -93,14 +91,14 @@ void StyleContactListDelegate::paint(QPainter *painter, const QStyleOptionViewIt
         const QString name = index.data(Qt::DisplayRole).value<QString>();
         if (!name.isEmpty()) {
             painter->setFont(QFont(option.font.family(), 11));
-            painter->drawText(nameTextRect, Qt::AlignLeft | Qt::AlignVCenter,
-                              painter->fontMetrics().elidedText(name, Qt::ElideRight, nameTextRect.width()));
+            painter->drawText(nameTextRect, Qt::AlignLeft | Qt::AlignVCenter, painter->fontMetrics().elidedText(name, Qt::ElideRight, nameTextRect.width()));
         }
 
         const QString description = index.data(ContactInfoProxyModel::Roles::DescriptionRole).value<QString>();
         if (!description.isEmpty()) {
             painter->setFont(QFont(option.font.family(), 8, -1, true));
-            painter->drawText(descriptionTextRect, Qt::AlignLeft | Qt::AlignVCenter,
+            painter->drawText(descriptionTextRect,
+                              Qt::AlignLeft | Qt::AlignVCenter,
                               painter->fontMetrics().elidedText(description, Qt::ElideRight, descriptionTextRect.width()));
         }
         return;
